@@ -308,8 +308,6 @@ class Phonetic_Manipulation():
 		word = re.sub(u'\u0361', '&', word)
 
 		new_word = []
-		x = 0
-		y = 0
 		affricate = []
 		diphthong = []
 		skip = False
@@ -355,7 +353,7 @@ class Phonetic_Manipulation():
 					skip = True
 				elif diphthong:
 					new_word[-1] = diphthong
-					skip=True
+					skip = True
 			else:
 				skip = False
 				continue
